auxjad
======

|PyPI| |Build| |Python versions| |License|  |Bug report|

``auxjad`` is a library of auxiliary functions and classes for Abjad 3.1. All
classes and functions have a __doc__ attribute with usage instructions.

Documentation is available at https://gilbertohasnofb.github.io/auxjad-docs/. A
pdf version of the documentation is also available in the ``/docs`` directory
of the repository.

Bugs can be reported through the project's `Issue Tracker`_.

This library is published under the `MIT License`_.


Installation
============

The recommended way to install ``auxjad`` is via `pip`_::

    ~$ pip install --user auxjad

Or if you are using virtual environments, simply use::

    ~$ pip install auxjad

You will also need to install `Python 3.6`_ or higher, as well as `Abjad`_ and
`LilyPond`_.


.. |PyPI| image:: https://img.shields.io/pypi/v/auxjad.svg
   :target: https://pypi.python.org/pypi/auxjad
.. |Build| image:: https://travis-ci.org/gilbertohasnofb/auxjad.svg?branch=master
   :target: https://travis-ci.org/gilbertohasnofb/auxjad
.. |Python versions| image:: https://img.shields.io/pypi/pyversions/auxjad.svg
.. |License| image:: https://img.shields.io/github/license/gilbertohasnofb/auxjad.svg
   :target: https://github.com/gilbertohasnofb/auxjad/blob/master/LICENSE
.. |Bug report| image:: https://img.shields.io/badge/bug-report-red.svg
   :target: https://github.com/gilbertohasnofb/auxjad/issues
..  _`Issue Tracker`: https://github.com/gilbertohasnofb/auxjad/issues
..  _`MIT License`: https://github.com/gilbertohasnofb/auxjad/blob/master/LICENSE
..  _pip: https://pip.pypa.io/en/stable/
..  _Python 3.6: https://www.python.org/
..  _Abjad: https://abjad.github.io/
..  _LilyPond: http://lilypond.org/
